function showDots (cohere, leftRight, ndots, duration)
% function showDots (cohere, leftRight, ndots, time)
% displays a movie of random dots with some fraction of the dots moving
% coherently to the left or right between adjacent frames. cohere is a 
% number between 0 and 1 that specifies the fraction of coherently moving
% dots. leftRight is 0 (move left) or 1 (move right). ndots is the total
% number of dots. duration is the total time the movie is shown in seconds

xc1 = rand(1,ndots);            % (x,y) coordinates for adjacent frames
yc1 = rand(1,ndots);
xc2 = zeros(1,ndots);
yc2 = zeros(1,ndots);
ncohere = fix(cohere*ndots);    % number of dots moving coherently L/R
nmove = ndots-ncohere;          % number of dots moving randomly
if leftRight                    % rightward or leftward step per frame
    step = 0.02;
else
    step = -0.02;
end
% number of frames, adjusted for computation time
nframes = fix(0.75*(duration/0.05));    
% tic;          % for testing timing
for t = 1:nframes       % create and display movie frames
    keep = ((xc1-0.5).^2 + (yc1-0.5).^2) < 0.25;    % circular aperture
    scatter(xc1(keep),yc1(keep),20,'k', 'filled');  % show next frame
    axis([0 1 0 1])
    axis square
    axis off
    pause(0.05)
    xc2(1:ncohere) = xc1(1:ncohere) + step;     % L/R coherent movement
    yc2(1:ncohere) = yc1(1:ncohere);
    dx = (0.04*rand(1,nmove))-0.02;             % random movement
    dy = (0.04*rand(1,nmove))-0.02;
    xc2((ncohere+1):end) = xc1((ncohere+1):end)+dx;
    yc2((ncohere+1):end) = yc1((ncohere+1):end)+dy;
    xc2(xc2 > 1) = 0;       % dots wrap around as needed
    xc2(xc2 < 0) = 1;
    yc2(yc2 > 1) = 0;
    yc2(xc2 < 0) = 1;
    xc1 = xc2;              % move new dots to xc1,xy1 for next cycle
    yc1 = yc2;
end
% disp(['time ' num2str(toc)])

        